#
# spec file for package python-tweepy
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-tweepy
Version:        3.6.0
Release:        3.1
Summary:        Twitter library for python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/tweepy/tweepy
Source:         https://github.com/tweepy/tweepy/archive/v%{version}.tar.gz
Patch0:         tweepy-pip2.10.patch
BuildRequires:  %{python_module PySocks >= 1.5.7}
BuildRequires:  %{python_module mock >= 1.0.1}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests >= 2.11.1}
BuildRequires:  %{python_module requests-oauthlib >= 0.7.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.10.0}
BuildRequires:  %{python_module vcrpy >= 1.0.1}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PySocks >= 1.5.7
Requires:       python-requests >= 2.11.1
Requires:       python-requests-oauthlib >= 0.7.0
Requires:       python-six >= 1.10.0
BuildArch:      noarch
%python_subpackages

%description
A library for accessing the Twitter.com API. Supports OAuth, covers the entire
API, and streaming API.

%prep
%setup -q -n tweepy-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
# do not install generic example folder
%python_expand rm -r %{buildroot}%{$python_sitelib}/examples
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Sadly tests need access to twitter api
#%%python_expand nosetests-%{$python_bin_suffix} -v tests.test_cursors tests.test_api tests.test_utils

%files %{python_files}
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Aug 10 2018 tchvatal@suse.com
- Do not pull in unittest2
* Wed May  2 2018 tchvatal@suse.com
- Switch to github tarball
- Update url
- Update to version 3.6.0:
  * Most notably support for python3 and various tweaks
- Add patch to work with new pip:
  * tweepy-pip2.10.patch
* Thu Feb 18 2016 eshmarnev@suse.com
- update to version 3.5.0:
  New features:
  * Allow 'full_text' param when getting direct messages.
  * Explicitly return api code when parsing error.
  * Remove deprecated function and clean up codes.
  Bug Fixes
  * update_status: first positional argument should be 'status'.
  * Fix "TypeError: Can't convert 'bytes' object to str implicitly".
  * Fix duplicate raise in auth.py.
  Additional changes from version 3.4.0:
  New features:
  * Add API for account/settings.
  * Added RateLimitError for easily working with the rate limit.
  * Allow include_email param for verify_credentials API.
  * Added support for the "filter_level" parameter for the streaming API.
  Bug Fixes:
  * Streaming: don't decode stream bytes until json.decode.
  * Typo fix on _add_list_members, _remove_list_members properties.
  * Change raise in streaming.py to raise exception.
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 3.3.0:
  * Loosen our dependency requirements for Requests (>= 2.4.3)
  * Fix issue with streams freezing up on Python 3 (Issue #556)
  * Add keep_alive() callback to StreamListener when keep alive
    messages arrive
  * Fix issue with stream session headers not being used when
    restarting connection
  * Fix issue with streams getting stuck in a loop when connection
    dies. (PR #561)
- additional changes from version 3.2.0
  * Remove deprecated trends methods.
  * Fix tweepy.debug() to work in Python 3.
  * Fixed issue #529 - StreamListener language filter stopped
    working.
  * Add Documentation Page for streaming.
  * Add media/upload endpoint.
  * Add media_ids parameter to update_status().
- additional changes from version 3.1.0
  * Allow specifying your own ssl certificates for streaming client.
  * Distribute Python Wheels instead of dumb binaries.
  * Fix cursor invocation, passing args to underlying method.
    (https://github.com/tweepy/tweepy/issues/515)
  * Upgrade to Request 2.4.3
- additional changes from version 3.0
  * Added multiple list members operation api methods
    (add_list_members, remove_list_members).
  * Added sitestream endpoint.
  * Switch to using Requests instead of httplib.
  * Fully removed support for non-secure HTTP.
  * Proxy support.
  * Add API method for /statuses/lookup.json
  * Add missing 'count' parameter to followers_ids
  * Added allowed_param to update_profile_image
  * Comparison between Status objects
  * Extend on_data method by including a conditional to process
    warning messages and add the definition of the method to manage
    those warning messages
  * Better Python 3 support.
- additional changes from version 2.2
  * Added update_profile_banner endpoint.
  * Don't treat HTTP status codes in 200 range as errors.
  * Tests no longer packaged into egg releases.
  * Improve test stability and enable CI testing on pull requests.
  * Removed Basic Auth.
  * Use built-in timeout feature of httplib to fix appengine.
  * Added retweeters() endpoint.
  * Removed deprecated retweeted_by and retweeted_by_ids.
  * Improved datetime parsing. Should be more thread safe.
  * Enable coverage reporting. Upload reports to Coveralls.
    https://coveralls.io/r/tweepy/tweepy
  * Removed deprecated test() endpoint.
  * New stream listeners callback on_disconnect(). Called whenever
    "disconnect" messages arrive from Twitter before connection is
    killed.
  * Compare View
  * Use HTTPS by default.
  * Support setting the starting cursor postion (ex: Ex:
    Cursor(api.friends_ids, cursor=123456))
  * Added API.cached_result instance flag that is "True" when
    cached result is returned.
  * New Streaming client callbacks
  * Improvements to streaming client re-connection behavior /
    configuration.
    (https://github.com/tweepy/tweepy/commit/447f69cd3de67b0d241b9d4
    f669ecc9b9c0cdb54)
- add new build dependency python-pip
- remove python-simplejson from dependencies
- add new dependencies python-requests, python-requests-oauthlib
  and python-six to match requirements.txt
- remove the examples directory from site package root
* Fri Nov 15 2013 p.drouand@gmail.com
- Update to version 2.1
  + No changelog available
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Feb 11 2013 p.drouand@gmail.com
- Update to version 2.0:
  * No changelog available
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to 1.12 version:
  * No changelog available
* Mon Jun 25 2012 saschpe@suse.de
- Update to version 1.9:
  + Upstream provides no changelog
* Tue May 31 2011 saschpe@suse.de
- Re-generated with py2pack
* Wed Sep 15 2010 pascal.bleser@opensuse.org
- initial version 1.7.1
